      subroutine triadvec  ( vec1, alpha1, vec2, bresul, nxa, nya,
     +           sl1, sl2, sl3, sl4)
c ======================================================================
c
c        programmer     Jos van Kan
c
c       version 1.1    10-04-1997
c         utilizes module mgpreset instead of common block cmgconst
c       version 1.0    27-03-1997
c
c
c   copyright (c) 1997
c   all rights reserved. no part of this publication may be reproduced,
c   stored in a retrieval system ( e.g., in memory, disk, or core)
c   or be transmitted by any means, electronic, mechanical, photocopy,
c   recording, or otherwise, without written permission from the
c   author.
c
c
c **********************************************************************
c
c                       DESCRIPTION
c
c   Adds alpha1 * vec2 to vec1 and stores bresul in bresul.
c   Vec1, vec2 and bresul are not necessarily different.
c **********************************************************************
c
c                       KEYWORDS
c
c   multi_grid
c **********************************************************************
c
c         MODULES USED
c
      use mgpreset
c
c **********************************************************************
c
c                       INPUT / OUTPUT PARAMETERS
c
      implicit none
      integer sl1, sl2, sl3, sl4
      integer nxa, nya
      double precision alpha1
      double precision
     + vec1 (1-sl1:nxa+sl2, 1-sl3:nya+sl4),
     + vec2 (1-sl1:nxa+sl2, 1-sl3:nya+sl4),
     + bresul (1-sl1:nxa+sl2, 1-sl3:nya+sl4)

c     alpha1    i    General constant alpha
c     bresul    o    The result vector
c     nxa       i    Number of grid x points on this level
c     nya       i    Number of grid y points on this level
c     sl1       i    Slack variable, x lower bound
c     sl2       i    Slack variable, x upper bound
c     sl3       i    Slack variable, y lower bound
c     sl4       i    Slack variable, y upper bound
c     vec1      i    Generic name for quantity with the dimension of
c                    sol or rhs
c     vec2      i    Generic name for quantity with the dimension of
c                    sol or rhs
c **********************************************************************
c
c                       LOCAL PARAMETERS
c
      integer ixa, iya

c     ixa       Counter to number of grid x points on this level
c     iya       Counter to number of grid y points on this level
c **********************************************************************
c
c                       I/O
c
c **********************************************************************
c
c                       ERROR MESSAGES
c
c **********************************************************************
c
c                       PSEUDO CODE
c
c **********************************************************************
c
c                       DATA STATEMENTS
c
c **********************************************************************
c
c                       SUBROUTINES CALLED
c
c **********************************************************************
c
c                       COMMON BLOCKS
c
c ======================================================================
c
      do iya = 1, nya
      do ixa = 1, nxa
        bresul (ixa, iya) = vec1 (ixa, iya) +  alpha1 * vec2 (ixa, iya)
      end do
      end do
      end
